package jalview.datamodel;

public interface ProfileI
{

  /**
   * Set the full profile of counts
   * 
   * @param residueCounts
   */
  public abstract void setCounts(ResidueCount residueCounts);

  /**
   * Returns the percentage identity of the profile, i.e. the highest proportion
   * of conserved (equal) symbols. The percentage is as a fraction of all
   * sequences, or only ungapped sequences if flag ignoreGaps is set true.
   * 
   * @param ignoreGaps
   * @return
   */
  public abstract float getPercentageIdentity(boolean ignoreGaps);

  /**
   * Returns the full symbol counts for this profile
   * 
   * @return
   */
  public abstract ResidueCount getCounts();

  /**
   * Returns the number of sequences in the profile
   * 
   * @return
   */
  public abstract int getHeight();

  /**
   * Returns the number of sequences in the profile which had a gap character
   * (or were too short to be included in this column's profile)
   * 
   * @return
   */
  public abstract int getGapped();

  /**
   * Returns the highest count for any symbol(s) in the profile
   * 
   * @return
   */
  public abstract int getMaxCount();

  /**
   * Returns the symbol (or concatenated symbols) which have the highest count
   * in the profile, or an empty string if there were no symbols counted
   * 
   * @return
   */
  public abstract String getModalResidue();

  /**
   * Answers the number of non-gapped sequences in the profile
   * 
   * @return
   */
  public abstract int getNonGapped();

}